" Y'ARE very snug in here," piped old Mr. Woodifield, and he peered out of the great, green leather armchair by his friend the boss's desk as a baby peers out of its pram. His talk was over; it was time for him to be off. But he did not want to go. Since he had retired, since his... stroke, the wife and the girls kept him boxed up in the house every day of the week except Tuesday. On Tuesday he was dressed and brushed and allowed to cut back to the City for the day. Though what he did there the wife and girls couldn't imagine. Made a nuisance of himself to his friends, they supposed ... Well, perhaps so. All the same, we cling to our last pleasures as the tree clings to its last leaves. So there sat old Woodifield, smoking a cigar and staring almost greedily at the boss, who rolled in his office chair, stout, rosy, five years older than he, and still going strong, still at the helm. It did one good to see him. Wistfully, admiringly, the old voice added, " It's snug in here, upon my word ! "

" Yes, it's comfortable enough," agreed the boss, and he flipped the Financial Times with a paper-knife. As a matter of fact he was proud of his room ; he liked to have it admired, especially by old Woodifield. It gave him a feeling of deep, solid satisfaction to be planted there in the midst of it in full view of that frail old figure in the muffler.

" I've had it done up lately," he explained, as he had explained for the past—how many ?— weeks. " New carpet," and he pointed to the bright red carpet with a pattern of large white rings. " New furniture," and he nodded towards the massive bookcase and the table with legs like twisted treacle. " Electric heating ! " He waved almost exultantly towards the five transparent, pearly sausages glowing so softly in the tilted copper pan.

But he did not draw old Woodifield's attention to the photograph over the table of a grave-looking boy in uniform standing in one of those spectral photographers' parks with photographers' storm-clouds behind him. It was not new. It had been there for over six years.

" There was something I wanted to tell you," said old Woodifield, and his eyes grew dim remembering. " Now what was it ? I had it in my mind when I started out this morning." His hands began to tremble, and patches of red showed above his beard.

Poor old chap, he's on his last pins, thought the boss. And, feeling kindly, he winked at the old man, and said jokingly, " I tell you what. I've got a little drop of something here that'll do you good before you go out into the cold again. It's beautiful stuff. It wouldn't hurt a child." He took a key off his watch-chain, unlocked a cupboard below his desk, and drew forth a dark, squat bottle. " That's the medicine," said he. " And the man from whom I got it told me on the strict Q.T. it came from the cellars at Windsor Cassel."

Old Woodifield's mouth fell open at the sight. He couldn't have looked more surprised if the boss had produced a rabbit.

" It's whisky, ain't it ? " he piped, feebly.

The boss turned the bottle and lovingly showed him the label. Whisky it was.

" D'you know," said he, peering up at the boss wonderingly, " they won't let me touch it at home." And he looked as though he was going to cry.

" Ah, that's where we know a bit more than the ladies," cried the boss, swooping across for two tumblers that stood on the table with the water-bottle, and pouring a generous finger into each. " Drink it down. It'll do you good. And don't put any water with it. It's sacrilege to tamper with stuff like this. Ah ! " He tossed off his, pulled out his handkerchief, hastily wiped his moustaches, and cocked an eye at old Woodifield, who was rolling his in his chaps.

The old man swallowed, was silent a moment, and then said faintly, " It's nutty ! "

But it warmed him ; it crept into his chill old brain—he remembered.

" That was it," he said, heaving himself out of his chair. " I thought you'd like to know. The girls were in Belgium last week having a look at poor Reggie's grave, and they happened to come across your boy's. They're quite near each other, it seems."

Old Woodifield paused, but the boss made no reply. Only a quiver in his eyelids showed that he heard.

" The girls were delighted with the way the place is kept," piped the old voice. " Beautifully looked after. Couldn't be better if they were at home. You've not been across, have yer ? "

" No, no ! " For various reasons the boss had not been across.

" There's miles of it," quavered old Woodifield, " and it's all as neat as a garden. Flowers growing on all the graves. Nice broad paths." It was plain from his voice how much he liked a nice broad path.

The pause came again. Then the old man brightened wonderfully.

" D'you know what the hotel made the girls pay for a pot of jam ? " he piped. " Ten - francs! Robbery, I call it. It was a little pot, so Gertrude says, no bigger than a half-crown. And she hadn't taken more than a spoonful when they charged her ten francs. Gertrude brought the pot away with her to teach 'em a lesson. Quite right, too ; it's trading on our feelings. They think because we're over there having a look round we're ready to pay anything. That's what it is." And he turned towards the door.

" Quite right, quite right! " cried the boss, though what was quite right he hadn't the least idea. He came round by his desk, followed the shuffling footsteps to the door, and saw the old fellow out. Woodifield was gone.

For a long moment the boss stayed, staring at nothing, while the grey-haired office messenger, watching him, dodged in and out of his cubby hole like a dog that expects to be taken for a run. Then : " I'll see nobody for half an hour, Macey," said the boss. " Understand ? Nobody at all."

" Very good, sir."

The door shut, the firm heavy steps recrossed the bright carpet, the fat body plumped down in the spring chair, and leaning forward, the boss covered his face with his hands. He wanted, he intended, he had arranged to weep...

It had been a terrible shock to him when old Woodifield sprang that remark upon him about the boy's grave. It was exactly as though the earth had opened and he had seen the boy lying there with Woodifield's girls staring down at him. For it was strange. Although over six years had passed away, the boss never thought of the boy except as lying unchanged, unblemished in his uniform, asleep for ever. " My son ! " groaned the boss. But no tears came yet. In the past, in the first months and even years after the boy's death, he had only to say those words to be overcome by such grief that nothing short of a violent fit of weeping could relieve him. Time, he had declared then, he had told everybody, could make no difference. Other men perhaps might recover, might live their loss down, but not he. How was it possible ? His boy was an only son. Ever since his birth the boss had worked at building up this business for him ; it had no other meaning if it was not for the boy. Life itself had come to have no other meaning. How on earth could he have slaved, denied himself, kept going all those years without the promise for ever before him of the boy's stepping into his shoes and carrying on where he left off ?

And that promise had been so near being fulfilled. The boy had been in the office learning the ropes for a year before the war. Every morning they had started off together ; they had come back by the same train. And what congratulations he had received as the boy's father ! No wonder ; he had taken to it marvellously. As to his popularity with the staff, every man jack of them down to old Macey couldn't make enough of the boy. And he wasn't in the least spoilt. No, he was just his bright, natural self, with the right word for everybody, with that boyish look and his habit of saying, " Simply splendid ! "

But all that was over and done with as though it never had been. The day had come when Macey had handed him the telegram that brought the whole place crashing about his head. " Deeply regret to inform you ..." And he had left the office a broken man, with his life in ruins.

Six years ago, six years ... How quickly time passed ! It might have happened yesterday. The boss took his hands from his face ; he was puzzled. Something seemed to be wrong with him. He wasn't feeling as he wanted to feel. He decided to get up and have a look at the boy's photograph. But it wasn't a favourite photograph of his; the expression was unnatural. It was cold, even stern-looking. The boy had never looked like that.

At that moment the boss noticed that a fly had fallen into his broad inkpot, and was trying feebly but desperately to clamber out again. Help ! help ! said those struggling legs. But the sides of the inkpot were wet and slippery ; it fell back again and began to swim. The boss took up a pen, picked the fly out of the ink, and shook it on to a piece of blotting-paper. For a fraction of a second it lay still on the dark patch that oozed round it. Then the front legs waved, took hold, and, pulling its small, sodden body up it began the immense task of cleaning the ink from its wings. Over and under, over and under, went a leg along a wing, as the stone goes over and under the scythe. Then there was a pause, while the fly, seeming to stand on the tips of its toes, tried to expand first one wing and then the other. It succeeded at last, and, sitting down, it began, like a minute cat, to clean its face. Now one could imagine that the little front legs rubbed against each other lightly, joyfully. The horrible danger was over ; it had escaped ; it was ready for life again.

But just then the boss had an idea. He plunged his pen back into the ink, leaned his thick wrist on the blotting paper, and as the fly tried its wings down came a great heavy blot. What would it make of that ? What indeed ! The little beggar seemed absolutely cowed, stunned, and afraid to move because of what would happen next. But then, as if painfully, it dragged itself forward. The front legs waved, caught hold, and, more slowly this time, the task began from the beginning.

He's a plucky little devil, thought the boss, and he felt a real admiration for the fly's courage. That was the way to tackle things ; that was the right spirit. Never say die ; it was only a question of ... But the fly had again finished its laborious task, and the boss had just time to refill his pen, to shake fair and square on the new-cleaned body yet another dark drop. What about it this time ? A painful moment of suspense followed. But behold, the front legs were again waving ; the boss felt a rush of relief. He leaned over the fly and said to it tenderly, " You artful little b . . ." And he actually had the brilliant notion of breathing on it to help the drying process. All the same, there was something timid and weak about its efforts now, and the boss decided that this time should be the last, as he dipped the pen deep into the inkpot.

It was. The last blot fell on the soaked blotting-paper, and the draggled fly lay in it and did not stir. The back legs were stuck to the body; the front legs were not to be seen.

" Come on," said the boss. " Look sharp ! " And he stirred it with his pen—in vain. Nothing happened or was likely to happen. The fly was dead.

The boss lifted the corpse on the end of the paper-knife and flung it into the waste-paper basket. But such a grinding feeling of wretchedness seized him that he felt positively frightened. He started forward and pressed the bell for Macey.

" Bring me some fresh blotting-paper," he said, sternly, " and look sharp about it." And while the old dog padded away he fell to wondering what it was he had been thinking about before. What was it ? It was... He took out his handkerchief and passed it inside his collar. For the life of him he could not remember.
